@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,9 +40,9 @@ const QString CMP_VERSION(QString());
 
 const QString QSTR_APPNAME("VMPK");
 const QString QSTR_DOMAIN("vmpk.sourceforge.net");
-const QString QSTR_VMPKPX("vmpk_");
-const QString QSTR_QTPX("qt_");
-const QString QSTR_DRUMSTICKPX("drumstick-widgets_");
+const QString QSTR_VMPKPX("vmpk");
+const QString QSTR_QTPX("qt");
+const QString QSTR_DRUMSTICKPX("drumstick-widgets");
 
 const QString QSTR_WINDOW("Window");
 const QString QSTR_GEOMETRY("Geometry");
