@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 
 #include <QApplication>
 #include <QSplashScreen>
+#include <QScreen>
 #include <QThread>
 #include <QTimer>
 #include <QCommandLineParser>
@@ -28,7 +29,7 @@
 
 const char* PGM_DESCRIPTION = QT_TRANSLATE_NOOP("QCoreApplication",
      "Virtual MIDI Piano Keyboard\n"
-     "Copyright (C) 2006-2022 Pedro Lopez-Cabanillas\n"
+     "Copyright (C) 2006-2023 Pedro Lopez-Cabanillas\n"
      "This program comes with ABSOLUTELY NO WARRANTY;\n"
      "This is free software, and you are welcome to redistribute it\n"
      "under certain conditions; see the LICENSE for details.");
@@ -45,6 +46,7 @@ int main(int argc, char *argv[])
     QCoreApplication::setApplicationVersion(PGM_VERSION);
     QCoreApplication::setAttribute(Qt::AA_SynthesizeMouseForUnhandledTouchEvents, false);
     QCoreApplication::setAttribute(Qt::AA_SynthesizeTouchForUnhandledMouseEvents, false);
+    QGuiApplication::setDesktopFileName("net.sourceforge.VMPK");
 #if defined(Q_OS_WINDOWS)
     QApplication::setStyle("fusion");
 #elif defined(Q_OS_LINUX)
@@ -69,16 +71,6 @@ int main(int argc, char *argv[])
         return 0;
     }
 
-    QPixmap px(":/vpiano/vmpk_splash.png");
-    QSplashScreen splash(px);
-    QFont sf = app.font();
-    sf.setPointSize(20);
-    splash.setFont(sf);
-    splash.show();
-    app.processEvents();
-    splash.showMessage("Virtual MIDI Piano Keyboard " + PGM_VERSION, Qt::AlignBottom | Qt::AlignRight);
-    app.processEvents();
-
     if (parser.isSet(portableOption) || parser.isSet(portableFileOption)) {
         QString portableFile;
         if (parser.isSet(portableFileOption)) {
@@ -93,11 +85,8 @@ int main(int argc, char *argv[])
     do {
         VPiano w;
         if (w.isInitialized()) {
-            splash.finish(&w);
             w.show();
             result_code = app.exec();
-        } else {
-            splash.close();
         }
     } while (result_code == RESTART_VMPK);
     return result_code;
