@@ -1,6 +1,6 @@
 /*
     MIDI Virtual Piano Keyboard
-    Copyright (C) 2008-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2008-2023, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -47,6 +47,7 @@
 #include <drumstick/rtmidioutput.h>
 #include <drumstick/pianokeybd.h>
 #include <drumstick/settingsfactory.h>
+#include <drumstick/configurationdialogs.h>
 
 #include "vpiano.h"
 #include "instrument.h"
@@ -1700,6 +1701,8 @@ void VPiano::slotImportSF()
         !dlgRiffImport->getOutput().isEmpty()) {
         dlgRiffImport->save();
         VPianoSettings::instance()->setInstruments(dlgRiffImport->getOutput(), dlgRiffImport->getName());
+        //set the soundfont in the output driver preferences:
+        drumstick::widgets::changeSoundFont(VPianoSettings::instance()->lastOutputBackend(), dlgRiffImport->getInput(), this);
         applyPreferences();
     }
     grabKb();
@@ -2070,6 +2073,7 @@ void VPiano::initLanguages()
     m_supportedLangs.insert(QLatin1String("es"), tr("Spanish"));
     m_supportedLangs.insert(QLatin1String("fr"), tr("French"));
     m_supportedLangs.insert(QLatin1String("gl"), tr("Galician"));
+    m_supportedLangs.insert(QLatin1String("it"), tr("Italian"));
     m_supportedLangs.insert(QLatin1String("nl"), tr("Dutch"));
     m_supportedLangs.insert(QLatin1String("ru"), tr("Russian"));
     m_supportedLangs.insert(QLatin1String("sr"), tr("Serbian"));
